@@ -18,15 +18,13 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
+#include "ksudoku_logging.h"
+
 #include "view2d.h"
 
-#include "view2d.moc" 
-
+#include <QDebug>
 #include <QGraphicsPixmapItem>
 #include <QGraphicsSceneEvent>
-#include <QtDebug> // IDW test.
-
-#include <kdebug.h>
 
 #include "puzzle.h"
 #include "gameactions.h"
@@ -55,8 +53,8 @@ public:
 	
 	void setValues(QVector<ColoredValue> values);
 protected:
-	void hoverEnterEvent(QGraphicsSceneHoverEvent* event);
-	void mousePressEvent(QGraphicsSceneMouseEvent* event);
+	void hoverEnterEvent(QGraphicsSceneHoverEvent* event) override;
+	void mousePressEvent(QGraphicsSceneMouseEvent* event) override;
 private:
 	void updatePixmap();
 private:
@@ -71,7 +69,7 @@ private:
 };
 
 CellGraphicsItem::CellGraphicsItem(QPoint pos, int id, View2DScene* scene) {
-	setAcceptsHoverEvents(true);
+	setAcceptHoverEvents(true);
 	setShapeMode(QGraphicsPixmapItem::BoundingRectShape);
 	m_pos = pos;
 	m_size = 0;
@@ -544,8 +542,8 @@ void View2DScene::setSceneSize(const QSize& size) {
 		m_cells[i]->resize(grid);
 	}
 	
-	for(int i = 0; i < m_groups.size(); ++i) {
-		m_groups[i]->resize(grid, m_highlightsOn);
+	for (ksudoku::GroupGraphicsItem* group : qAsConst(m_groups)) {
+		group->resize(grid, m_highlightsOn);
 	}
 	
 	m_cursor->setPixmap(Renderer::instance()->renderSpecial(SpecialCursor, grid*2));
@@ -553,9 +551,9 @@ void View2DScene::setSceneSize(const QSize& size) {
 
 void View2DScene::hover(int cell) {
 	m_cursorPos = cell;
-// 	qDebug() << "hover cell" << cell << m_cells[cell];
+// 	qCDebug(KSudokuLog) << "hover cell" << cell << m_cells[cell];
 	QPoint pos(m_cells[cell]->pos());
-	foreach(GroupGraphicsItem* item, m_groups) {
+	for (GroupGraphicsItem* item : qAsConst(m_groups)) {
 		item->setHighlight(pos, m_highlightsOn);
 	}
 	
@@ -633,7 +631,7 @@ void View2DScene::update(int cell) {
 
 void View2DScene::updateCage (int cageNumP1, bool drawLabel) {
 	if (cageNumP1 == 0) {
-	    qDebug() << "ERROR: View2DScene::updateCage: cageNumP1 == 0.";
+	    qCDebug(KSudokuLog) << "ERROR: View2DScene::updateCage: cageNumP1 == 0.";
 	    return;
 	}
 	SKGraph* g    = m_game.puzzle()->graph();
